#ifndef NT2_INCLUDE_FUNCTIONS_RSHL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RSHL_HPP_INCLUDED

#include <nt2/bitwise/include/functions/rshl.hpp>

#endif
